/*==========================================================================
 *
 *
 *  Version 1.00
 *
 * Copyright (C) Allan Petersen.  All Rights Reserved.
 * Permission to use, copy, modify, and distribute this software for
 * any purpose and without fee is hereby granted, provided that the above
 * copyright notice appear in all copies and that both the copyright notice
 * and this permission notice appear in supporting documentation, and that
 * the name of Allan Petersen not be used in advertising
 * or publicity pertaining to distribution of the software without specific,
 * written prior permission.
 *
 * THE MATERIAL EMBODIED ON THIS SOFTWARE IS PROVIDED TO YOU "AS-IS"
 * AND WITHOUT WARRANTY OF ANY KIND, EXPRESS, IMPLIED OR OTHERWISE,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTY OF MERCHANTABILITY OR
 * FITNESS FOR A PARTICULAR PURPOSE.  IN NO EVENT SHALL ALLAN
 * PETERSEN BE LIABLE TO YOU OR ANYONE ELSE FOR ANY DIRECT,
 * SPECIAL, INCIDENTAL, INDIRECT OR CONSEQUENTIAL DAMAGES OF ANY
 * KIND, OR ANY DAMAGES WHATSOEVER, INCLUDING WITHOUT LIMITATION,
 * LOSS OF PROFIT, LOSS OF USE, SAVINGS OR REVENUE, OR THE CLAIMS OF
 * THIRD PARTIES, WHETHER OR NOT ALLAN PETERSEN HAS BEEN
 * ADVISED OF THE POSSIBILITY OF SUCH LOSS, HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, ARISING OUT OF OR IN CONNECTION WITH THE
 * POSSESSION, USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 *--------------------------------------------------------------------------
 *
 * Contact Allan Petersen at <allan.petersen@danbbs.dk> or visit
 * www.danbbs.dk/~allmette
 *
 *==========================================================================
 */
//---------------------------------------------------------------------------

#include <vcl.h>
#pragma hdrstop

#include "mmsystem.h"	// For mci functions
#include "main.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
#pragma link "Trayicon"
#pragma resource "*.dfm"
TForm1 *Form1;
//---------------------------------------------------------------------------
__fastcall TForm1::TForm1(TComponent* Owner)
    : TForm(Owner)
{
	// Determine All avalable CD Drives to add them to the listbox
    int nPos = 0;
    UINT nCount = 0;
    TCHAR szDrive[4];
	strcpy(szDrive, "?:\\");
    TMenuItem       *pItem;

    DWORD dwDriveList = ::GetLogicalDrives ();

    while (dwDriveList) {
        if (dwDriveList & 1) {
            szDrive[0] = 0x41 + nPos;
			if(GetDriveType(szDrive) == DRIVE_CDROM) {
                ListBox1->Items->Add (szDrive);
                }
            }
        dwDriveList >>= 1;
        nPos++;
        }
}
//==========================================================================
// Open or Close CD Drive
// cDrive is Drive Letter to Open, or 1 for 'Default' drive
// Examples:
//    CD_OpenCloseDrive(TRUE, 'E');   // Open CD Door for Drive E:
//    CD_OpenCloseDrive(FALSE, 'E');  // Close CD Door for Drive E:
//    CD_OpenCloseDrive(TRUE, 1);     // Open First Logical CD Drive Door
//==========================================================================
void TForm1::CD_OpenCloseDrive(BOOL bOpenDrive, TCHAR cDrive)
{
	MCI_OPEN_PARMS op;
	DWORD flags;
    int   rc;
    char    errstr[256];

	TCHAR szDriveName[4];
	strcpy(szDriveName, "X:");

    Screen->Cursor = crHourGlass;
    StatusBar1->SimpleText = "Attaching to CD-Drive";
    // ---- Clear structure with zoro
	memset (&op, NULL, sizeof(MCI_OPEN_PARMS));
    // ---- Setting device type to CD
	op.lpstrDeviceType = (LPCSTR) MCI_DEVTYPE_CD_AUDIO;

    // ---- Check for 'E' or '1' entered
	if(cDrive > 1)	{
		szDriveName[0] = cDrive;
		op.lpstrElementName = szDriveName;
		flags = MCI_OPEN_TYPE | MCI_OPEN_TYPE_ID | MCI_OPEN_ELEMENT | MCI_OPEN_SHAREABLE;
	    }
	else
        flags = MCI_OPEN_TYPE | MCI_OPEN_TYPE_ID | MCI_OPEN_SHAREABLE;

    // ---- Connect to devide
	if (!mciSendCommand(0,MCI_OPEN,flags,(unsigned long)&op))	{
        // ---- Select open / close
		if (bOpenDrive) {
            StatusBar1->SimpleText = "Opening Door, please wait...";
			rc = mciSendCommand(op.wDeviceID,MCI_SET,MCI_SET_DOOR_OPEN,0);
            }
		else {
            StatusBar1->SimpleText = "Closing Door, please wait...";
			rc = mciSendCommand(op.wDeviceID,MCI_SET,MCI_SET_DOOR_CLOSED,0);
            }
        // ---- Close connection to device and wait for ready
		mciSendCommand(op.wDeviceID,MCI_CLOSE,MCI_WAIT,0);
	    }
    StatusBar1->SimpleText = "";
    Screen->Cursor = crDefault;
}
//---------------------------------------------------------------------------
void __fastcall TForm1::ButtonOpenClick(TObject *Sender)
{
    if (ListBox1->ItemIndex == -1) return;
    ButtonOpen->Enabled   = false;
    ButtonClose->Enabled  = false;
    CD_OpenCloseDrive(true, ListBox1->Items->Strings[ListBox1->ItemIndex].c_str()[0]);
    ButtonOpen->Enabled   = true;
    ButtonClose->Enabled  = true;
}
//---------------------------------------------------------------------------
void __fastcall TForm1::ButtonCloseClick(TObject *Sender)
{
    if (ListBox1->ItemIndex == -1) return;
    ButtonOpen->Enabled   = false;
    ButtonClose->Enabled  = false;
    CD_OpenCloseDrive(false, ListBox1->Items->Strings[ListBox1->ItemIndex].c_str()[0]);
    ButtonOpen->Enabled   = true;
    ButtonClose->Enabled  = true;
}
//---------------------------------------------------------------------------
